==> openshift-client-5.0.2-sources.jar: io/fabric8/openshift/client/handlers/RangeAllocationHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.RangeAllocationOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.RangeAllocation;
import io.fabric8.openshift.api.model.RangeAllocationBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class RangeAllocationHandler implements ResourceHandler<RangeAllocation, RangeAllocationBuilder> {

  @Override
  public String getKind() {
    return RangeAllocation.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "security.openshift.io/v1";
    }

  @Override
  public RangeAllocation create(OkHttpClient client, Config config, String namespace, RangeAllocation item) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public RangeAllocation replace(OkHttpClient client, Config config, String namespace, RangeAllocation item) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public RangeAllocation reload(OkHttpClient client, Config config, String namespace, RangeAllocation item) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public RangeAllocationBuilder edit(RangeAllocation item) {
    return new RangeAllocationBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, RangeAllocation item) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, RangeAllocation item, Watcher<RangeAllocation> watcher) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, RangeAllocation item, String resourceVersion, Watcher<RangeAllocation> watcher) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, RangeAllocation item, ListOptions options, Watcher<RangeAllocation> watcher) {
  return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public RangeAllocation waitUntilReady(OkHttpClient client, Config config, String namespace, RangeAllocation item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public RangeAllocation waitUntilCondition(OkHttpClient client, Config config, String namespace, RangeAllocation item, Predicate<RangeAllocation> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> openshift-client-5.2.0-sources.jar: io/fabric8/openshift/client/handlers/RangeAllocationHandler.java <==

                            

package io.fabric8.openshift.client.handlers;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.openshift.client.dsl.internal.RangeAllocationOperationsImpl;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;

import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.openshift.api.model.RangeAllocation;
import io.fabric8.openshift.api.model.RangeAllocationBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class RangeAllocationHandler implements ResourceHandler<RangeAllocation, RangeAllocationBuilder> {

  @Override
  public String getKind() {
    return RangeAllocation.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
      return "security.openshift.io/v1";
    }

  @Override
  public RangeAllocation create(OkHttpClient client, Config config, String namespace, RangeAllocation item, boolean dryRun) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public RangeAllocation replace(OkHttpClient client, Config config, String namespace, RangeAllocation item, boolean dryRun) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public RangeAllocation reload(OkHttpClient client, Config config, String namespace, RangeAllocation item) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public RangeAllocationBuilder edit(RangeAllocation item) {
    return new RangeAllocationBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, RangeAllocation item, boolean dryRun) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, RangeAllocation item, Watcher<RangeAllocation> watcher) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, RangeAllocation item, String resourceVersion, Watcher<RangeAllocation> watcher) {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, RangeAllocation item, ListOptions options, Watcher<RangeAllocation> watcher) {
  return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }


  @Override
  public RangeAllocation waitUntilReady(OkHttpClient client, Config config, String namespace, RangeAllocation item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public RangeAllocation waitUntilCondition(OkHttpClient client, Config config, String namespace, RangeAllocation item, Predicate<RangeAllocation> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new RangeAllocationOperationsImpl(client, OpenShiftConfig.wrap(config)).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
